==> windmill-api-1.5.0.tar.gz: windmill-api-1.5.0/windmill_api/api/group/add_user_to_group.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...models.add_user_to_group_json_body import AddUserToGroupJsonBody
from ...types import Response


def _get_kwargs(
    workspace: str,
    name: str,
    *,
    client: Client,
    json_body: AddUserToGroupJsonBody,
) -> Dict[str, Any]:
    url = "{}/w/{workspace}/groups/adduser/{name}".format(client.base_url, workspace=workspace, name=name)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _build_response(*, response: httpx.Response) -> Response[Any]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    workspace: str,
    name: str,
    *,
    client: Client,
    json_body: AddUserToGroupJsonBody,
) -> Response[Any]:
    """add user to group

    Args:
        workspace (str):
        name (str):
        json_body (AddUserToGroupJsonBody):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        name=name,
        client=client,
        json_body=json_body,
    )

    response = httpx.post(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    workspace: str,
    name: str,
    *,
    client: Client,
    json_body: AddUserToGroupJsonBody,
) -> Response[Any]:
    """add user to group

    Args:
        workspace (str):
        name (str):
        json_body (AddUserToGroupJsonBody):

    Returns:
        Response[Any]
    """

    kwargs = _get_kwargs(
        workspace=workspace,
        name=name,
        client=client,
        json_body=json_body,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)

==> windmill-api-1.24.0.tar.gz: windmill-api-1.24.0/windmill_api/api/group/add_user_to_group.py <==
from typing import Any, Dict

import httpx

from ...client import Client
from ...models.add_user_to_group_json_body import AddUserToGroupJsonBody
from ...types import Response


def _get_kwargs(
    *,
    client: Client,
    workspace: str,
    name: str,
    json_body: AddUserToGroupJsonBody,
) -> Dict[str, Any]:
    url = "{}/w/{workspace}/groups/adduser/{name}".format(client.base_url, workspace=workspace, name=name)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    json_json_body = json_body.to_dict()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "json": json_json_body,
    }


def _build_response(*, response: httpx.Response) -> Response[None]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=None,
    )


def sync_detailed(
    *,
    client: Client,
    workspace: str,
    name: str,
    json_body: AddUserToGroupJsonBody,
) -> Response[None]:
    kwargs = _get_kwargs(
        client=client,
        workspace=workspace,
        name=name,
        json_body=json_body,
    )

    response = httpx.post(
        **kwargs,
    )

    return _build_response(response=response)


async def asyncio_detailed(
    *,
    client: Client,
    workspace: str,
    name: str,
    json_body: AddUserToGroupJsonBody,
) -> Response[None]:
    kwargs = _get_kwargs(
        client=client,
        workspace=workspace,
        name=name,
        json_body=json_body,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.post(**kwargs)

    return _build_response(response=response)
